@@ -72,6 +72,7 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
                                                      const gchar               *object,
                                                      GError                   **error);
 void     tracker_data_begin_transaction             (GError                   **error);
+void     tracker_data_begin_ontology_transaction    (GError                   **error);
 void     tracker_data_begin_transaction_for_replay  (time_t                     time,
                                                      GError                   **error);
 void     tracker_data_commit_transaction            (GError                   **error);
@@ -88,10 +89,7 @@ void     tracker_data_load_turtle_file              (GFile                     *
                                                      GError                   **error);
 
 void     tracker_data_sync                          (void);
-void     tracker_data_replay_journal                (GHashTable                *classes,
-                                                     GHashTable                *properties,
-                                                     GHashTable                *id_uri_map,
-                                                     TrackerBusyCallback        busy_callback,
+void     tracker_data_replay_journal                (TrackerBusyCallback        busy_callback,
                                                      gpointer                   busy_user_data,
                                                      const gchar               *busy_status);
 
