@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2006, Laurent Aguerreche (laurent.aguerreche@free.fr)
- * Copyright (C) 2007, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2006, Laurent Aguerreche <laurent.aguerreche@free.fr>
+ * Copyright (C) 2007, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -69,8 +69,10 @@ typedef struct {
 } MetadataExtractor;
 
 static void extract_gstreamer_helix_audio (const gchar          *uri,
+                                           TrackerSparqlBuilder *preupdate,
                                            TrackerSparqlBuilder *metadata);
 static void extract_gstreamer_helix_video (const gchar          *uri,
+                                           TrackerSparqlBuilder *preupdate,
                                            TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
@@ -370,7 +372,9 @@ add_int64_info (TrackerSparqlBuilder *metadata,
                 const gchar        *key,
                 gint64      info)
 {
-	tracker_statement_list_insert_with_int64 (metadata, uri, key, info);
+	tracker_sparql_builder_subject_iri (metadata, uri);
+	tracker_sparql_builder_predicate_iri (metadata, key);
+	tracker_sparql_builder_object_int64 (metadata, info);
 }
 
 static void
@@ -379,7 +383,9 @@ add_uint_info (TrackerSparqlBuilder *metadata,
                gchar      *key,
                guint       info)
 {
-	tracker_statement_list_insert_with_int (metadata, uri, key, info);
+	tracker_sparql_builder_subject_iri (metadata, uri);
+	tracker_sparql_builder_predicate_iri (metadata, key);
+	tracker_sparql_builder_object_int64 (metadata, info);
 }
 
 static void
@@ -397,7 +403,9 @@ add_string_gst_tag (TrackerSparqlBuilder        *metadata,
 
 	if (s) {
 		if (ret && s[0] != '\0') {
-			tracker_statement_list_insert (metadata, uri, key, s);
+			tracker_sparql_builder_subject_iri (metadata, uri);
+			tracker_sparql_builder_predicate_iri (metadata, key);
+			tracker_sparql_builder_object_unvalidated (metadata, s);
 		}
 
 		g_free (s);
@@ -417,7 +425,9 @@ add_uint_gst_tag (TrackerSparqlBuilder  *metadata,
 	ret = gst_tag_list_get_uint (tag_list, tag, &n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_int (metadata, uri, key, n);
+		tracker_sparql_builder_subject_iri (metadata, uri);
+		tracker_sparql_builder_predicate_iri (metadata, key);
+		tracker_sparql_builder_object_int64 (metadata, n);
 	}
 }
 
@@ -434,7 +444,9 @@ add_double_gst_tag (TrackerSparqlBuilder        *metadata,
 	ret = gst_tag_list_get_double (tag_list, tag, &n);
 
 	if (ret) {
-		tracker_statement_list_insert_with_double (metadata, uri, key, n);
+		tracker_sparql_builder_subject_iri (metadata, uri);
+		tracker_sparql_builder_predicate_iri (metadata, key);
+		tracker_sparql_builder_object_double (metadata, n);
 	}
 }
 
@@ -455,8 +467,9 @@ add_year_of_gdate_gst_tag (TrackerSparqlBuilder  *metadata,
 		gchar buf[10];
 
 		if (g_date_strftime (buf, 10, "%Y", date)) {
-			tracker_statement_list_insert (metadata, uri,
-			                               key, buf);
+			tracker_sparql_builder_subject_iri (metadata, uri);
+			tracker_sparql_builder_predicate_iri (metadata, key);
+			tracker_sparql_builder_object_unvalidated (metadata, buf);
 		}
 	}
 
@@ -765,7 +778,8 @@ poll_for_state_change (MetadataExtractor *extractor,
 
 static void
 tracker_extract_gstreamer_helix (const gchar *uri,
-                                 TrackerSparqlBuilder  *metadata,
+                                 TrackerSparqlBuilder *preupdate,
+                                 TrackerSparqlBuilder *metadata,
                                  ExtractMime    type)
 {
 	MetadataExtractor *extractor;
@@ -828,7 +842,7 @@ tracker_extract_gstreamer_helix (const gchar *uri,
 	tracker_albumart_process (extractor->album_art_data,
 	                          extractor->album_art_size,
 	                          NULL,
-	                          /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
+	                          artist,
 	                          album,
 	                          uri);
 
@@ -845,15 +859,19 @@ tracker_extract_gstreamer_helix (const gchar *uri,
 }
 
 static void
-extract_gstreamer_helix_audio (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_helix_audio (const gchar          *uri,
+                               TrackerSparqlBuilder *preupdate,
+			       TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer_helix (uri, metadata, EXTRACT_MIME_AUDIO);
+	tracker_extract_gstreamer_helix (uri, preupdate, metadata, EXTRACT_MIME_AUDIO);
 }
 
 static void
-extract_gstreamer_helix_video (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_helix_video (const gchar          *uri,
+                               TrackerSparqlBuilder *preupdate,
+			       TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer_helix (uri, metadata, EXTRACT_MIME_VIDEO);
+	tracker_extract_gstreamer_helix (uri, preupdate, metadata, EXTRACT_MIME_VIDEO);
 }
 
 TrackerExtractData *
